<?php
/*
Plugin Name: 123 Extended Gallery
Plugin URI: http://schnurpsel.de/wordpress-plugins/123-extended-gallery/
Description: Erweitert die WP-Gallery um den Parameter attlink ('none', 'image', 'permalink'). Standardvorgaben für Link, Anzahl der Spalten und Verwendung des Stylesheets können konfiguriert werden.
Author: Ingo Henze
Version: 0.17
Author URI: http://putzlowitsch.de/
*/ 

// Einstellungen für das Plugin
$plw123ega_options_default = array(
	'gallery_columns' => 3, // Anzahl Bilder je Spalte 
	'link_to' => 1 ,   			// Standardlink bei Galeriebildern (0=none, 1=file, 2=post)
	'default_css' => true		// Standard-Galerie-Stylesheet im Header einbinden
);

// Einstellungen laden
$plw123ega_options = get_option( 'plw123ega_options' );
// noch keine vorhanden, dann mit Default-Werten vorbelegen
if( !is_array( $plw123ega_options ) ) {
	$plw123ega_options = $plw123ega_options_default;
}
// wenn vorhanden, gegebenenfalls nicht vorhandene Default-Werte hinzufügen
else {
	$plw123ega_options = array_merge( $plw123ega_options_default, $plw123ega_options );
}

// erweiterte WP-Gallerie-Funktion
function plw123ega_gallery_shortcode( $input, $attr ) {
	global $post, $wp_locale;
	global $plw123ega_options;

	static $instance = 0;
	$instance++;

	// We're trusting author input, so let's at least make sure it looks like a valid orderby statement
	if ( isset( $attr['orderby'] ) ) {
		$attr['orderby'] = sanitize_sql_orderby( $attr['orderby'] );
		if ( !$attr['orderby'] )
			unset( $attr['orderby'] );
	}
	extract(shortcode_atts(array(
		'order'      => 'ASC',
		'orderby'    => 'menu_order ASC, ID ASC',
		'id'         => $post->ID,
		'itemtag'    => 'dl',
		'icontag'    => 'dt',
		'captiontag' => 'dd',
		'columns'    => $plw123ega_options['gallery_columns'],
		'size'       => 'thumbnail',
		'exclude'    => '',
		'include'    => '',
		'imgstyle'	 => 0,
	), $attr));

  	
	$attlink = '';	
	// Anpassung für link-Attribut ab WP 2.7
	// Plugin-Parameter
	if( isset( $attr['attlink'] ) ) {
		$attlink = $attr['attlink'];
	}
	// Link-Parameter ab WP 2.7
	elseif( isset( $attr['link'] ) ) {
		$attlink = $attr['link'];
	}
	// Linkparameter heißt ab WP 2.7 'file'
	if( 'file' == $attlink )
		$attlink = image;
		
	// Falls leer, Standard aus den Optionen setzen
	if( '' == $attlink ) {
		switch( $plw123ega_options['link_to'] ) {
			case 0: $attlink = 'none'; break;
			case 1: $attlink = 'image'; break;
			case 2: $attlink = 'permalink'; break;
		}	
	}
	
	$id = intval($id);
	if ( 'RAND' == $order )
		$orderby = 'none';

	if ( !empty($include) ) {
		$include = preg_replace( '/[^0-9,]+/', '', $include );
		$_attachments = get_posts( array('include' => $include, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );

		$attachments = array();
		foreach ( $_attachments as $key => $val ) {
			$attachments[$val->ID] = $_attachments[$key];
		}
	} elseif ( !empty($exclude) ) {
		$exclude = preg_replace( '/[^0-9,]+/', '', $exclude );
		$attachments = get_children( array('post_parent' => $id, 'exclude' => $exclude, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );
	} else {
		$attachments = get_children( array('post_parent' => $id, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );
	}

	if ( empty($attachments) )
		return '???';

	if ( is_feed() ) {
		$output = "\n";
		foreach ( $attachments as $att_id => $attachment )
			$output .= wp_get_attachment_link($att_id, $size, $attlink=='permalink') . "\n";
		return $output;
	}

	$itemtag = tag_escape($itemtag);
	$captiontag = tag_escape($captiontag);
	$columns = intval($columns);
	$itemwidth = $columns > 0 ? floor(100/$columns) : 100;
	$itemwidth -= 0.1;

	$selector = "gallery-{$instance}";
	
	if( $imgstyle ) {
		$itemtag = 'div';
	}
	
	$output = "<div id='$selector' class='gallery galleryid-{$id}'>\n";

	$i = 0;
	foreach ( $attachments as $id => $attachment ) {
		if( $attlink=='none' )
			$link = wp_get_attachment_image( $id, $size );
		else
			$link = wp_get_attachment_link( $id, $size, $attlink=='permalink' );

		$output .= "<{$itemtag} class='gallery-item' style='width: {$itemwidth}%;'>";
		if( $imgstyle ) {
			$caption_text = wptexturize($attachment->post_excerpt);
			if( !$caption_text )
				$caption_text = '&nbsp;';
			$output .= "<div class='wp-caption'>$link<p class='wp-caption-text'>$caption_text</p></div>";
;
		}
		else {
			$output .= "
				<{$icontag} class='gallery-icon'>
					$link
				</{$icontag}>";
			if ( $captiontag && trim($attachment->post_excerpt) ) {
				$output .= "
					<{$captiontag} class='gallery-caption'>
					" . wptexturize($attachment->post_excerpt) . "
					</{$captiontag}>";
			}
		}
		$output .= "</{$itemtag}>";
		if ( $columns > 0 && ++$i % $columns == 0 )
			$output .= '<br style="clear: both" />';
	}

	$output .= "
			<br style='clear: both;' />
		</div>\n";
	
	return $output;
}

// CSS für Galerie ausgeben
function plw123ega_gallery_css() {
	if( function_exists( 'is_rtl' ) ) 
		$float = is_rtl() ? 'right' : 'left';
	else
		$float = 'left';
	$output = apply_filters('gallery_style', "
		<style type='text/css'>
			.gallery {
				margin: auto;
			}
			.gallery-item {
				float: $float;
				margin-top: 10px;
				text-align: center;
			}
			.gallery img {
				border: 2px solid #cfcfcf;
			}
			.gallery-caption {
				margin-left: 0;
			}
		</style>");
	echo $output;	
}
add_filter( 'post_gallery', 'plw123ega_gallery_shortcode', 10, 2 );

if( $plw123ega_options['default_css'] )
	add_action( 'wp_head', 'plw123ega_gallery_css' );

// Admin-Panel
if( WP_ADMIN == true ) :
function plw123ega_options_subpanel() {
	global $plw123ega_options;
	global $wp_rewrite;

  if (isset($_POST['plw123ega_update'])) {
		// Optionen
		$value = trim($_POST['plw123ega_opt_lto']);
		// Wertebereich prüfen
		if( !is_numeric($value) || $value<0 || $value>2 ) {
		  $value = 0;
		}
		$plw123ega_options['link_to'] = $value;

		// Galerie-Spalten
		$value = trim($_POST['plw123ega_opt_col']);
		// Wertebereich prüfen zwischen 2 und 9
		if( !is_numeric($value) || $value<2 || $value>9 ) {
		  $value = 3;
		}
		$plw123ega_options['gallery_columns'] = $value;
	
		$plw123ega_options['default_css'] = isset($_POST['plw123ega_opt_uds']);

		update_option('plw123ega_options', $plw123ega_options );	
		
    ?><div class="updated"><p><strong>Einstellungen wurden gespeichert.</strong></p></div>
	<?php
  }
	$plugindata = get_plugin_data( __FILE__, false, true );
	?>
<div class="wrap" style="height:100%">
  <form method="post" id="plw123tpl_optform" onsubmit="return createLists()">
	<?php screen_icon(); ?>
    <h2>Einstellungen › <?php echo $plugindata['Title']; ?></h2>
	<p>Plugin-Version <?php echo $plugindata['Version']; ?></p>
	<p><?php echo $plugindata['Description']; ?></p>
    <h3>Optionen</h3>
	<table class="editform form-table" style='vertical-align:baseline;'>
<tr valign="top"><th scope="row">Vorschaubild verlinken  mit</th>
<td>
	<label><input type="radio" name="plw123ega_opt_lto" value="0" <?php if($plw123ega_options['link_to']==0) echo 'checked="checked"'; ?> /> nichts (kein Link)</label><br />
	<label><input type="radio" name="plw123ega_opt_lto" value="1" <?php if($plw123ega_options['link_to']==1) echo 'checked="checked"'; ?> /> dem Bild (Datei direkt)</label><br />
	<label><input type="radio" name="plw123ega_opt_lto" value="2" <?php if($plw123ega_options['link_to']==2) echo 'checked="checked"'; ?> /> der Anhang-Seite</label><br />
</td>
</tr>
<tr valign="top"><th scope="row">Standardanzahl Galeriespalen</th>
<td>
	<label><select name='plw123ega_opt_col' size='1' style='width:5em;'>
<?php
for( $i=2; $i<=9; $i++ ) {
	if( $i==$plw123ega_options['gallery_columns'] )
	  $selected = " selected";
	else	
	  $selected = "";
	echo "<option value='$i'$selected>$i</option>\n";
}
?>
	</select></label><br />
</td>
</tr>
	<tr><th><label>WP Stylesheet verwenden: </label></th><td><input type="checkbox" name="plw123ega_opt_uds" value="1" <?php if($plw123ega_options['default_css']) echo 'checked="checked"'; ?> /><label> deaktivieren, um ein eigenes Stylesheet zu verwenden, die Galerie-Styleklassen bleiben erhalten</label></td></tr>
	</table>
<div class="submit" style="clear:both;">
  <input type="submit" name="plw123ega_update" class="button-primary" value="<?php _e('Save Changes') ?>" />
</div>
  </form>
 </div>
 <?php 
}

function plw123ega_add_admin_panel() {
	if (function_exists('add_options_page')) {
		add_options_page('123 Extended Gallery', '123 Extended Gallery', 8, basename(__FILE__), 'plw123ega_options_subpanel');
    }
 }

add_action( 'admin_menu', 'plw123ega_add_admin_panel' );
endif;

?>